summaryrefslogtreecommitdiff
path: root/lib/Pod/Text
diff options
context:
space:
mode:
authorJarkko Hietaniemi <jhi@iki.fi>2001-07-10 13:16:11 +0000
committerJarkko Hietaniemi <jhi@iki.fi>2001-07-10 13:16:11 +0000
commit3c01495985c7c4b8f1b95ec88b49209869fdb517 (patch)
tree2cb1993aeb1659927e86984b98ebfd7bb024d193 /lib/Pod/Text
parent110e9fb061b90cb31e677034a6540c4ffa0c288c (diff)
downloadperl-3c01495985c7c4b8f1b95ec88b49209869fdb517.tar.gz
Upgrade to podlators 1.10.
p4raw-id: //depot/perl@11255
Diffstat (limited to 'lib/Pod/Text')
-rw-r--r--lib/Pod/Text/Color.pm40
-rw-r--r--lib/Pod/Text/Overstrike.pm36
-rw-r--r--lib/Pod/Text/Termcap.pm38
3 files changed, 66 insertions, 48 deletions
diff --git a/lib/Pod/Text/Color.pm b/lib/Pod/Text/Color.pm
index e943216d88..f747a967ec 100644
--- a/lib/Pod/Text/Color.pm
+++ b/lib/Pod/Text/Color.pm
@@ -1,18 +1,18 @@
# Pod::Text::Color -- Convert POD data to formatted color ASCII text
-# $Id: Color.pm,v 0.6 2000/12/25 12:52:39 eagle Exp $
+# $Id: Color.pm,v 1.0 2001/07/10 11:03:43 eagle Exp $
#
# Copyright 1999 by Russ Allbery <rra@stanford.edu>
#
# This program is free software; you can redistribute it and/or modify it
# under the same terms as Perl itself.
#
-# This is just a basic proof of concept. It should later be modified to
-# make better use of color, take options changing what colors are used for
-# what text, and the like.
+# This is just a basic proof of concept. It should later be modified to make
+# better use of color, take options changing what colors are used for what
+# text, and the like.
-############################################################################
+##############################################################################
# Modules and declarations
-############################################################################
+##############################################################################
package Pod::Text::Color;
@@ -26,16 +26,15 @@ use vars qw(@ISA $VERSION);
@ISA = qw(Pod::Text);
-# Don't use the CVS revision as the version, since this module is also in
-# Perl core and too many things could munge CVS magic revision strings.
-# This number should ideally be the same as the CVS revision in podlators,
-# however.
-$VERSION = 0.06;
+# Don't use the CVS revision as the version, since this module is also in Perl
+# core and too many things could munge CVS magic revision strings. This
+# number should ideally be the same as the CVS revision in podlators, however.
+$VERSION = 1.00;
-############################################################################
+##############################################################################
# Overrides
-############################################################################
+##############################################################################
# Make level one headings bold.
sub cmd_head1 {
@@ -79,9 +78,9 @@ sub wrap {
$output;
}
-############################################################################
+##############################################################################
# Module return value and documentation
-############################################################################
+##############################################################################
1;
__END__
@@ -123,6 +122,13 @@ L<Pod::Text|Pod::Text>, L<Pod::Parser|Pod::Parser>
=head1 AUTHOR
-Russ Allbery E<lt>rra@stanford.eduE<gt>.
+Russ Allbery <rra@stanford.edu>.
+
+=head1 COPYRIGHT AND LICENSE
+
+Copyright 1999 by Russ Allbery <rra@stanford.edu>.
+
+This program is free software; you may redistribute it and/or modify it
+under the same terms as Perl itself.
=cut
@@ -1,18 +1,18 @@
# Copyright 1999 by Russ Allbery <rra@stanford.edu>
#
-# This program is free software; you can redistribute it and/or modify it
+# This program is free software; you may redistribute it and/or modify it
# under the same terms as Perl itself.
#
diff --git a/lib/Pod/Text/Overstrike.pm b/lib/Pod/Text/Overstrike.pm
index c9f0789d06..be159f4080 100644
--- a/lib/Pod/Text/Overstrike.pm
+++ b/lib/Pod/Text/Overstrike.pm
@@ -1,10 +1,10 @@
# Pod::Text::Overstrike -- Convert POD data to formatted overstrike text
-# $Id: Overstrike.pm,v 1.1 2000/12/25 12:51:23 eagle Exp $
+# $Id: Overstrike.pm,v 1.2 2001/07/10 11:04:36 eagle Exp $
#
# Created by Joe Smith <Joe.Smith@inwap.com> 30-Nov-2000
# (based on Pod::Text::Color by Russ Allbery <rra@stanford.edu>)
#
# This program is free software; you can redistribute it and/or modify it
# under the same terms as Perl itself.
#
# This was written because the output from:
@@ -18,9 +18,9 @@
# and because both Pod::Text::Color and Pod::Text::Termcap are not device
# independent.
-############################################################################
+##############################################################################
# Modules and declarations
-############################################################################
+##############################################################################
package Pod::Text::Overstrike;
@@ -33,16 +33,15 @@ use vars qw(@ISA $VERSION);
@ISA = qw(Pod::Text);
-# Don't use the CVS revision as the version, since this module is also in
-# Perl core and too many things could munge CVS magic revision strings.
-# This number should ideally be the same as the CVS revision in podlators,
-# however.
-$VERSION = 1.01;
+# Don't use the CVS revision as the version, since this module is also in Perl
+# core and too many things could munge CVS magic revision strings. This
+# number should ideally be the same as the CVS revision in podlators, however.
+$VERSION = 1.02;
-############################################################################
+##############################################################################
# Overrides
-############################################################################
+##############################################################################
# Make level one headings bold, overridding any existing formatting.
sub cmd_head1 {
@@ -103,9 +102,9 @@ sub wrap {
$output;
}
-############################################################################
+##############################################################################
# Module return value and documentation
-############################################################################
+##############################################################################
1;
__END__
@@ -154,7 +153,14 @@ L<Pod::Text|Pod::Text>, L<Pod::Parser|Pod::Parser>
=head1 AUTHOR
-Joe Smith E<lt>Joe.Smith@inwap.comE<gt>, using the framework created by Russ
-Allbery E<lt>rra@stanford.eduE<gt>.
+Joe Smith <Joe.Smith@inwap.com>, using the framework created by Russ Allbery
+<rra@stanford.edu>.
+
+=head1 COPYRIGHT AND LICENSE
+
+Copyright 2000 by Joe Smith <Joe.Smith@inwap.com>.
+
+This program is free software; you may redistribute it and/or modify it
+under the same terms as Perl itself.
=cut
@@ -1,10 +1,10 @@
# (based on Pod::Text::Color by Russ Allbery <rra@stanford.edu>)
#
-# This program is free software; you can redistribute it and/or modify it
+# This program is free software; you may redistribute it and/or modify it
# under the same terms as Perl itself.
#
diff --git a/lib/Pod/Text/Termcap.pm b/lib/Pod/Text/Termcap.pm
index 333852a425..c49e2c3f96 100644
--- a/lib/Pod/Text/Termcap.pm
+++ b/lib/Pod/Text/Termcap.pm
@@ -1,18 +1,18 @@
# Pod::Text::Termcap -- Convert POD data to ASCII text with format escapes.
-# $Id: Termcap.pm,v 1.0 2000/12/25 12:52:48 eagle Exp $
+# $Id: Termcap.pm,v 1.1 2001/07/10 11:04:36 eagle Exp $
#
# Copyright 1999 by Russ Allbery <rra@stanford.edu>
#
# This program is free software; you can redistribute it and/or modify it
# under the same terms as Perl itself.
#
# This is a simple subclass of Pod::Text that overrides a few key methods to
-# output the right termcap escape sequences for formatted text on the
-# current terminal type.
+# output the right termcap escape sequences for formatted text on the current
+# terminal type.
-############################################################################
+##############################################################################
# Modules and declarations
-############################################################################
+##############################################################################
package Pod::Text::Termcap;
@@ -27,16 +27,15 @@ use vars qw(@ISA $VERSION);
@ISA = qw(Pod::Text);
-# Don't use the CVS revision as the version, since this module is also in
-# Perl core and too many things could munge CVS magic revision strings.
-# This number should ideally be the same as the CVS revision in podlators,
-# however.
-$VERSION = 1.00;
+# Don't use the CVS revision as the version, since this module is also in Perl
+# core and too many things could munge CVS magic revision strings. This
+# number should ideally be the same as the CVS revision in podlators, however.
+$VERSION = 1.01;
-############################################################################
+##############################################################################
# Overrides
-############################################################################
+##############################################################################
# In the initialization method, grab our terminal characteristics as well as
# do all the stuff we normally do.
@@ -105,9 +104,9 @@ sub wrap {
}
-############################################################################
+##############################################################################
# Module return value and documentation
-############################################################################
+##############################################################################
1;
__END__
@@ -140,6 +139,13 @@ L<Pod::Text|Pod::Text>, L<Pod::Parser|Pod::Parser>
=head1 AUTHOR
-Russ Allbery E<lt>rra@stanford.eduE<gt>.
+Russ Allbery <rra@stanford.edu>.
+
+=head1 COPYRIGHT AND LICENSE
+
+Copyright 1999 by Russ Allbery <rra@stanford.edu>.
+
+This program is free software; you may redistribute it and/or modify it
+under the same terms as Perl itself.
=cut
@@ -1,18 +1,18 @@
# Copyright 1999 by Russ Allbery <rra@stanford.edu>
#
-# This program is free software; you can redistribute it and/or modify it
+# This program is free software; you may redistribute it and/or modify it
# under the same terms as Perl itself.
#